==> haskell-io-streams-haproxy-1.0.1.0-276-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-HuAhRYJn9ibLRqKm32CVMk
key:                  io-streams-haproxy-1.0.1.0-HuAhRYJn9ibLRqKm32CVMk
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  33bd5a856315b4c0a54c136293308032
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.2.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-streams-haproxy
hs-libraries:         HSio-streams-haproxy-1.0.1.0-HuAhRYJn9ibLRqKm32CVMk
depends:
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    bytestring-0.11.4.0 io-streams-1.5.2.2-6SGR25X7anB2y3sILEGjaX
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.1.0-305.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-5Y9LdacOw9I2LHMvkICZYV
key:                  io-streams-haproxy-1.0.1.0-5Y9LdacOw9I2LHMvkICZYV
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  020e7e11e330e92e39adfb6ccbee07bc
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-streams-haproxy
hs-libraries:         HSio-streams-haproxy-1.0.1.0-5Y9LdacOw9I2LHMvkICZYV
depends:
    attoparsec-0.14.4-K9rgVNreKMkFhZdMbsqsTo base-4.17.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-AobX4ZC0WcD6Ru2kYgy993
    network-3.1.4.0-AQGzws0tmah75qbsifMDHb transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
